@@ -1,10 +1,5 @@
 """
 Functions to work with strings.
-
-    - transform_string_to_r_b,
-    - transform_string_to_digits,
-    - transform_fraction_with_label_to_string,
-    - transform_digits_to_string
 """
 
 from typing import Tuple, Union
@@ -16,17 +11,56 @@ def ciftext_to_html(text: str) -> str:
     """Convert cif text to html format."""
     l_text_new = []
     for line in text.split("\n"):
-        if line.find("_") == -1:
-            line_new = f"<b>{line:}</b>"
+        if line.strip().startswith("###"):
+            line_new = f"<h3>{line:}</h3>"
+        elif line.strip().startswith("##"):
+            line_new = f"<h2>{line:}</h2>"
+        elif line.strip().startswith("#"):
+            line_new = f"<h1>{line:}</h1>"
         else:
-            line_new = " ".join([f"<b>{word:}</b>" if word.find("_") == -1
-                                 else word for word in line.split(" ")])
+            line_new = line
         l_text_new.append(line_new)
     text_html = "<br>".join(l_text_new)
     # text_html = "<b>"+text.replace("\n", "<br>")+"<\b>"
     return text_html
 
 
+def find_prefix(*argv) -> str:
+    """Find prefix
+    
+    Example 1 (trivial)
+    -------------------
+    
+    loop_
+    _atom_site_label
+    _atom_site_fract_x
+    _atom_site_fract_y
+    
+    Output: "_atom_site"
+
+    Example 2 (not trivial)
+    -----------------------
+    loop_
+        _geom_torsion
+        _geom_torsion_atom_site_label_1
+        _geom_torsion_atom_site_label_2
+    
+    Output: "_geom_torsion"
+    (name for item "geom_torsion" is label)
+    
+    """
+    c_string = common_string(*argv)
+    ind_point = c_string.rfind(".")
+    if ind_point != -1:
+        prefix = c_string[:ind_point]
+    elif ((len(argv) > 1) & (c_string in argv)):
+        prefix = c_string
+    else:
+        ind_und = c_string.rfind("_")
+        prefix = c_string[:ind_und]
+    return prefix
+
+
 def common_string(*argv) -> str:
     """Return common begining of input strings."""
     ls_out = []
